Index: chrome/android/java/src/org/chromium/chrome/browser/payments/PaymentApp.java |
diff --git a/chrome/android/java/src/org/chromium/chrome/browser/payments/PaymentApp.java b/chrome/android/java/src/org/chromium/chrome/browser/payments/PaymentApp.java |
index b7cf36579bd31615c41acf65dcdb2ed76d3b9f36..55ecc47c260f0e9ff5c2f4a0d184c19d9e73f8d2 100644 |
--- a/chrome/android/java/src/org/chromium/chrome/browser/payments/PaymentApp.java |
+++ b/chrome/android/java/src/org/chromium/chrome/browser/payments/PaymentApp.java |
@@ -33,14 +33,16 @@ public interface PaymentApp { |
* cards for the current profile. Can return null or empty list, e.g., if user has no locally |
* stored credit cards. |
* |
* @param methodDataMap The map from methods to method specific data. The data contains such |
* information as whether the app should be invoked in test or production |
* mode, merchant identifier, or a public key. |
* @param origin The origin of this merchant. |
* @param callback The object that will receive the list of instruments. |
*/ |
void getInstruments(Map<String, PaymentMethodData> methodDataMap, String origin, |
- InstrumentsCallback callback); |
+ byte[][] certificateChain, InstrumentsCallback callback); |
/** |
* Returns a list of all payment method names that this app supports. For example, ["visa", |
@@ -33,14 +33,16 @@ public interface PaymentApp { |
* stored credit cards. |
* |
- * @param methodDataMap The map from methods to method specific data. The data contains such |
- * information as whether the app should be invoked in test or production |
- * mode, merchant identifier, or a public key. |
- * @param origin The origin of this merchant. |
- * @param callback The object that will receive the list of instruments. |
+ * @param methodDataMap The map from methods to method specific data. The data contains such |
+ * information as whether the app should be invoked in test or |
+ * production |
+ * mode, merchant identifier, or a public key. |
+ * @param origin The origin of this merchant. |
+ * @param certificateChain The site certificate chain of the merchant. |
+ * @param callback The object that will receive the list of instruments. |
*/ |
void getInstruments(Map<String, PaymentMethodData> methodDataMap, String origin, |